/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2013 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.scheduling;

/**
 * Runtime exception thrown in cases when thread is interrupted. Semantical meaning is almost same as
 * {@link InterruptedException} except this one is unchecked exception.
 * 
 * @author cstamas
 */
public class TaskInterruptedException
    extends RuntimeException
{
    private static final long serialVersionUID = 5758132070000732555L;

    private final boolean cancelled;

    public TaskInterruptedException( String message, boolean cancelled )
    {
        super( message );

        this.cancelled = cancelled;
    }

    public TaskInterruptedException( String message, Throwable cause )
    {
        super( message, cause );

        this.cancelled = false;
    }

    public TaskInterruptedException( Throwable cause )
    {
        super( cause );

        this.cancelled = false;
    }

    public boolean isCancelled()
    {
        return cancelled;
    }
}
